# Single Sign On

Wallaroo supports user authentication with single sign on (SSO) with the following providers:
* Google
* GitHub
* Azure

Single sign on limits access to the system via the UI and the SDK to authorized users, who must log in.

For more information about enabling single sign on, please reach out to your Wallaroo support contact.
